==> oci-java-sdk-datascience-1.34.0-sources.jar: com/oracle/bmc/datascience/model/WorkRequestOperationType.java <==
/**
 * Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datascience.model;

/**
 * The types of work request operations.
 **/
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20190101")
@lombok.extern.slf4j.Slf4j
public enum WorkRequestOperationType {
    NotebookSessionCreate("NOTEBOOK_SESSION_CREATE"),
    NotebookSessionDelete("NOTEBOOK_SESSION_DELETE"),
    NotebookSessionActivate("NOTEBOOK_SESSION_ACTIVATE"),
    NotebookSessionDeactivate("NOTEBOOK_SESSION_DEACTIVATE"),
    ModelDeploymentCreate("MODEL_DEPLOYMENT_CREATE"),
    ModelDeploymentDelete("MODEL_DEPLOYMENT_DELETE"),
    ModelDeploymentActivate("MODEL_DEPLOYMENT_ACTIVATE"),
    ModelDeploymentDeactivate("MODEL_DEPLOYMENT_DEACTIVATE"),
    ModelDeploymentUpdate("MODEL_DEPLOYMENT_UPDATE"),
    ProjectDelete("PROJECT_DELETE"),
    WorkrequestCancel("WORKREQUEST_CANCEL"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private final String value;
    private static java.util.Map<String, WorkRequestOperationType> map;

    static {
        map = new java.util.HashMap<>();
        for (WorkRequestOperationType v : WorkRequestOperationType.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    WorkRequestOperationType(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static WorkRequestOperationType create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'WorkRequestOperationType', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}

==> oci-java-sdk-datascience-2.46.0-sources.jar: com/oracle/bmc/datascience/model/WorkRequestOperationType.java <==
/**
 * Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
package com.oracle.bmc.datascience.model;

/**
 * The types of work request operations.
 **/
@javax.annotation.Generated(value = "OracleSDKGenerator", comments = "API Version: 20190101")
public enum WorkRequestOperationType {
    NotebookSessionCreate("NOTEBOOK_SESSION_CREATE"),
    NotebookSessionDelete("NOTEBOOK_SESSION_DELETE"),
    NotebookSessionActivate("NOTEBOOK_SESSION_ACTIVATE"),
    NotebookSessionDeactivate("NOTEBOOK_SESSION_DEACTIVATE"),
    ExportModelArtifact("EXPORT_MODEL_ARTIFACT"),
    ImportModelArtifact("IMPORT_MODEL_ARTIFACT"),
    ModelDeploymentCreate("MODEL_DEPLOYMENT_CREATE"),
    ModelDeploymentDelete("MODEL_DEPLOYMENT_DELETE"),
    ModelDeploymentActivate("MODEL_DEPLOYMENT_ACTIVATE"),
    ModelDeploymentDeactivate("MODEL_DEPLOYMENT_DEACTIVATE"),
    ModelDeploymentUpdate("MODEL_DEPLOYMENT_UPDATE"),
    ProjectDelete("PROJECT_DELETE"),
    WorkrequestCancel("WORKREQUEST_CANCEL"),
    JobDelete("JOB_DELETE"),

    /**
     * This value is used if a service returns a value for this enum that is not recognized by this
     * version of the SDK.
     */
    UnknownEnumValue(null);

    private static final org.slf4j.Logger LOG =
            org.slf4j.LoggerFactory.getLogger(WorkRequestOperationType.class);

    private final String value;
    private static java.util.Map<String, WorkRequestOperationType> map;

    static {
        map = new java.util.HashMap<>();
        for (WorkRequestOperationType v : WorkRequestOperationType.values()) {
            if (v != UnknownEnumValue) {
                map.put(v.getValue(), v);
            }
        }
    }

    WorkRequestOperationType(String value) {
        this.value = value;
    }

    @com.fasterxml.jackson.annotation.JsonValue
    public String getValue() {
        return value;
    }

    @com.fasterxml.jackson.annotation.JsonCreator
    public static WorkRequestOperationType create(String key) {
        if (map.containsKey(key)) {
            return map.get(key);
        }
        LOG.warn(
                "Received unknown value '{}' for enum 'WorkRequestOperationType', returning UnknownEnumValue",
                key);
        return UnknownEnumValue;
    }
}
